/*import { App } from './base/index.js'

import { TemplateLike } from './components/index.js'


let app = new App()
app.component(TemplateLike)
app.mount('#app')


class Valami {

}*/

/*Object.defineProperty(Valami, 'value', {get: function () {
    return 2
    }})

console.log(Valami.value)*/
/*class Point {
    +Point(point) { console.log(this) }
}*/

class A {
    method1() {

    }
}

let a = new A()
console.log(typeof a.method1)
